{% extends 'musette/base_musette.html' %}

{% load i18n %}

{% block content %}

<div class="reset-background">
    <div class="container">
        <div id="loginbox" class="mainbox col-md-6 col-md-offset-3 col-sm-6 col-sm-offset-3">
            <br>
            <div class="panel panel-default" >
                <div class="panel-heading">
                    <div class="panel-title text-center">{% trans "Reset password" %}</div>
                </div>

                <div class="panel-body">
                    <form action="{% url 'password_reset' %}" class="form-horizontal" method="post">{% csrf_token%}

                           <div class="input-group">
                            <span class="input-group-addon"><i class="fa fa-user"></i></span>
                              <input id="id_{{form.email.name}}" required="required" placeholder="{% trans 'Email' %}" maxlength="254" class="form-control" name="{{form.email.name}}" type="email">
                          </div>
                          {% if form.email.errors %}
                              <div style="color: red">{{ form.email.errors|safe|striptags }}</div>
                              <br>
                          {% else %}
                              <br>
                          {% endif %}

                        {{ messages.errors }}
                        <button type="submit" class="btn btn-default">{% trans "Submit" %}</button>
                    </form>

                </div>
            </div>
           </div>
    </div>
</div>

{% endblock %}
