# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2017-01-24 18:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('musette', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='forum',
            name='name',
            field=models.CharField(max_length=80, verbose_name='Name'),
        ),
    ]
