{% extends 'musette/base_musette.html' %}

{% load i18n %}
{% load static %}

{% block extra_js %}
	<!-- For TinyMce -->
    {{ form.media.js }}
{% endblock %}

{% block content %}

<div class="container">

	<div class="mainbox col-md-10 col-sm-6 col-sm-offset-1">
		<div class="panel panel-default" >
            <div class="panel-heading">
                <div class="panel-title text-center">{% trans "Edit profile" %}</div>
            </div>

            <div class="panel-body">
            	<form action="{{request.get_full_path}}" method="POST" enctype="multipart/form-data" name="editProfile">
            		{% csrf_token%}
            		{{ form.as_p }}
			        <button type="submit" class="btn btn-inverse btn-sm">
			        	<i class="fa fa-floppy-o"></i>
			        	{% trans "Save" %}
			        </button>
				</form>
            </div>
        </div>
	</div>

</div>


{% endblock %}