{% extends "musette/base_musette.html" %}

{% load i18n %}

{% block content %}
<div class="confirm-background">
    <br>
    <div class="container" style="width: 50%;">
        <div class="row">
            <div class="panel panel-success">
                  <div class="panel-heading">
                    <h3 class="panel-title">{% trans "Congratulations" %}</h3>
                  </div>
                  <div class="panel-body" style="min-height: 12em">
                    <h4>{% trans "Confirmation email" %}</h4>
                    <hr>
                    {% trans "Congratulations, you are now an active member of " %} {{ SETTINGS.SITE_NAME }}
                    <br>
                    {% trans "Thank you: " %} <b>{{ username }}</b>
                </div>
                <div class="panel-footer">
                    <a href="{% url 'login' %}" class="btn btn-default btn-sm btn-block">{% trans "Log in" %}</a>
                </div>
            </div>
        </div>
    </div>
    <br>
</div>
{% endblock %}
