{% extends 'musette/base_musette.html' %}

{% load i18n %}
{% load static %}

{% block content %}

<div class="container">

    <div class="row">
      <ul class="breadcrumb">
          <li><a href="{% url 'forums' %}">{% trans "Forums" %}</a></li>
          <li class="active">{% trans "Notifications" %}</li>
      </ul>
    </div>

    <div class="endless_page_template">
        <div class="panel panel-default" >
            <div class="panel-heading">
                <div class="panel-title">{% trans "Notifications" %}</div>
            </div>
            <div id="notifications-items" class="panel-body" v-endless-pagination="{'paginateOnScroll': true}">
                {% include "musette/all_notification.html" %}
            </div>
        </div>
    </div>
</div>
{% endblock %}
