{% extends "admin/base_site.html" %}
{% load i18n l10n admin_urls %}

{% block breadcrumbs %}
  <ul class="breadcrumb">
    <li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
      <span class="divider">&raquo;</span></li>
    <li>
      <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{% firstof opts.app_config.verbose_name app_label|capfirst|escape %}</a>
      <span class="divider">&raquo;</span></li>
    <li>
      <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
      <span class="divider">&raquo;</span></li>
    <li class="active">{% trans 'Delete multiple objects' %}</li>
  </ul>
{% endblock %}

{% block content %}
  {% if perms_lacking or protected %}
    {% if perms_lacking %}
      <div class="alert alert-error">
        {% blocktrans %}Deleting the selected {{ objects_name }} would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endblocktrans %}
        <ul>
          {% for obj in perms_lacking %}
            <li>{{ obj }}</li>
          {% endfor %}
        </ul>
      </div>
    {% endif %}
    {% if protected %}
      <div class="alert alert-error">
        {% blocktrans %}Deleting the selected {{ objects_name }} would require deleting the following protected related objects:{% endblocktrans %}
        <ul>
          {% for obj in protected %}
            <li>{{ obj }}</li>
          {% endfor %}
        </ul>
      </div>
    {% endif %}
  {% else %}

    <form action="" method="post">{% csrf_token %}
        <div class="alert alert-block alert-error">
          <h4 class="alert-heading">{% trans 'Confirm deletion' %}</h4>
          <p>
            {% blocktrans %}Are you sure you want to delete the selected {{ objects_name }}? All of the following objects and their related items will be deleted:{% endblocktrans %}</p>
           {% for deletable_object in deletable_objects %}
                <ul>{{ deletable_object|unordered_list }}</ul>
           {% endfor %}
          <br>

          <div>
            {% for id in ids %}
                <input type="hidden" name="{{ action_checkbox_name }}" value="{{ id.0 }}" />
            {% endfor %}
            <input type="hidden" name="action" value="{{ action }}" />
            <input type="hidden" name="post" value="yes" />
            <input type="submit" value="{% trans "Yes, I'm sure" %}" class="btn btn-danger"/>
          </div>
        </div>
    </form>
  {% endif %}
{% endblock %}