# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2017-03-04 22:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('musette', '0006_auto_20170206_0017'),
    ]

    operations = [
        migrations.AddField(
            model_name='configuration',
            name='description',
            field=models.TextField(blank=True, verbose_name='Description'),
        ),
    ]
