# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2017-01-25 00:56
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('musette', '0002_auto_20170124_1509'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='forum',
            unique_together=set([('category', 'name')]),
        ),
    ]
