{% extends "musette/base_musette.html" %}
{% load i18n %}

{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; {% trans 'Password reset' %}
</div>
{% endblock %}

{% block content %}

<div class="reset-background">
    <div class="container" style="padding-top: 2em">
        <br>
        <div class="well">
        <h3>{% trans "Congratulations" %}</h3>
        <hr>
        <p>{% trans "Your password has been set.  You may go ahead and log in now." %}</p>

        <p><a href="{% url 'login' %}">{% trans 'Log in' %}</a></p>
        <hr>
        </div>
    </div>
</div>

{% endblock %}
