{% extends "musette/base_musette.html" %}

{% load i18n %}

{% block content %}
<div class="confirm-background">
    <br>
    <div class="container" style="width: 50%;">
        <div class="row">
            {% if new_key %}
                <div class="alert alert-info alert-dismissible" role="alert">
                  <button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                  {% trans "Please, check your email." %}
                </div>
            {% endif %}
            <div class="panel panel-danger">
                  <div class="panel-heading">
                    <h3 class="panel-title">{% trans "The activation key has expired" %}</h3>
                  </div>
                  <div class="panel-body" style="min-height: 12em">
                    <h4>{% trans "Confirmation email" %}</h4>
                    <hr>
                    {% trans "The activation key has expired" %}
                    <br>
                    {% trans "Please click the following button to get a new activation key." %}
                </div>
                <div class="panel-footer">
                    <form action="{% url 'new_key_activation' username %}" method="POST">{% csrf_token %}
                    <input type="submit" class="btn btn-default btn-sm btn-block" value='{% trans "New activation key" %}' />
                </div>
            </div>
        </div>
    </div>
    <br>
</div>
{% endblock %}
