{% extends 'musette/base_musette.html' %}

{% load i18n %}
{% load static %}

{% block content %}

<div class="container">

	<div class="row">
      <ul class="breadcrumb">
          <li><a href="{% url 'forums' %}">{% trans "Forums" %}</a></li>
          <li><a href="{% url 'forum' forum.category forum %}">{{forum}}</a></li>
          <li class="active">{% trans "Find Topics" %}</li>
      </ul>
    </div>

	<div class="endless_page_template">
		<div class="panel panel-default" >
	        <div class="panel-heading">
	            <div class="panel-title">{% trans "Find Topics" %}</div>
	        </div>
	        <div id="search-items" class="panel-body" v-endless-pagination="{'paginateOnScroll': true, 'paginateOnScrollMargin': 180}">
	        	{% include "musette/topic_search.html" %}
	        </div>
	    </div>
	</div>
</div>
{% endblock %}
