{% extends 'musette/base_musette.html' %}

{% load i18n %}
{% load static %}
{% load forum_tags %}

{% block content %}

<div class="container">
    <ul class="breadcrumb">
        <li><a href="{% url 'forums' %}">{% trans "Forums" %}</a></li>
        <li><a href="{% url 'forum' forum.category forum %}">{{ forum }}</a></li>
        <li class="active">{% trans "Forum members" %}</li>
    </ul>

    <h4>{% trans "Forum members" %}: <a href="{% url 'forum' forum.category forum %}">{{forum}}</a></h4>

    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">
                <h5>
                    {% trans "Moderator" %}:
                    <span>
                        {% for moderator in forum.moderators.all %}
                            {{ moderator|get_path_profile|safe }}
                        {% endfor %}
                    </span>
                </h5>
            </h3>
        </div>
        <div id="users-items" class="panel-body" v-endless-pagination="{'paginateOnScroll': true}">
            {% include 'musette/users_forum.html' %}
        </div>
    </div>
</div>

{% endblock %}
